Learn R Programming

GANPA (version 1.2)

weight.gsets.with.msprot: Weight genes in pathways with a gene association network after correction for multi-subunit proteins

Description

Given a gene functional association network and a list of multi-subunit proteins, the gene weights in a list of pathways are assigned with a procedure of correction for multi-subunit proteins.

Usage

weight.gsets.with.msprot(gsets, isets.multi, msp.groups)

Value

A list of named numeric vectors storing gene weights, with gene names in the vector names.

Arguments

gsets

A gene association network stored in a list.

isets.multi

Pathways stored in the form of a list of gene sets.

msp.groups

A list of multi-subunit proteins.

Author

Zhaoyuan Fang, Weidong Tian and Hongbin Ji

References

Zhaoyuan Fang, Weidong Tian and Hongbin Ji. A Network-Based Gene Weighting Approach for Pathway Analysis. Submitted.

See Also

weight.gsets.test