Given a gene functional association network and a list of multi-subunit proteins, the gene weights in a list of pathways are assigned with a procedure of correction for multi-subunit proteins.
weight.gsets.with.msprot(gsets, isets.multi, msp.groups)A list of named numeric vectors storing gene weights, with gene names in the vector names.
A gene association network stored in a list.
Pathways stored in the form of a list of gene sets.
A list of multi-subunit proteins.
Zhaoyuan Fang, Weidong Tian and Hongbin Ji
Zhaoyuan Fang, Weidong Tian and Hongbin Ji. A Network-Based Gene Weighting Approach for Pathway Analysis. Submitted.
weight.gsets.test